@@ -1,14 +1,22 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: MPL-2.0
+
 package fix
 
 import (
-	"github.com/mitchellh/mapstructure"
 	"regexp"
+
+	"github.com/mitchellh/mapstructure"
 )
 
 // FixerCreateTime is a Fixer that replaces the ".CreateTime" template
 // calls with "{{timestamp}"
 type FixerCreateTime struct{}
 
+func (FixerCreateTime) DeprecatedOptions() map[string][]string {
+	return map[string][]string{}
+}
+
 func (FixerCreateTime) Fix(input map[string]interface{}) (map[string]interface{}, error) {
 	// Our template type we'll use for this fixer only
 	type template struct {
